@@ -63,7 +63,7 @@ class HookDispatcher:
         .. code-block:: python
 
             @schemathesis.hooks.register
-            def before_generate_query(strategy, context):
+            def before_generate_query(context, strategy):
                 ...
 
         With a hook name as the first argument:
@@ -71,7 +71,7 @@ class HookDispatcher:
         .. code-block:: python
 
             @schemathesis.hooks.register("before_generate_query")
-            def hook(strategy, context):
+            def hook(context, strategy):
                 ...
         """
         if isinstance(hook, str):
@@ -91,7 +91,7 @@ class HookDispatcher:
 
         .. code-block:: python
 
-            def before_generate_query(strategy, context):
+            def before_generate_query(context, strategy):
                 ...
 
 
@@ -212,6 +212,11 @@ def before_generate_body(context: HookContext, strategy: st.SearchStrategy) -> s
     """Called on a strategy that generates values for ``body``."""
 
 
+@all_scopes
+def before_generate_case(context: HookContext, strategy: st.SearchStrategy["Case"]) -> st.SearchStrategy["Case"]:
+    """Called on a strategy that generates ``Case`` instances."""
+
+
 @all_scopes
 def before_process_path(context: HookContext, path: str, methods: Dict[str, Any]) -> None:
     """Called before API path is processed."""
