@@ -131,6 +131,7 @@ def handle_schema_error(
         assert error.path is not None
         assert error.full_path is not None
         method = error.method.upper()
+        verbose_name = f"{method} {error.path}"
         result = TestResult(
             method=method,
             path=error.full_path,
@@ -141,6 +142,7 @@ def handle_schema_error(
         yield events.BeforeExecution(
             method=method,
             path=error.full_path,
+            verbose_name=verbose_name,
             relative_path=error.path,
             recursion_level=recursion_level,
             correlation_id=correlation_id,
