@@ -14,17 +14,16 @@ from urllib.parse import quote, unquote, urljoin, urlsplit, urlunsplit
 import attr
 import hypothesis
 from hypothesis.strategies import SearchStrategy
-from hypothesis.utils.conventions import InferType
 from requests.structures import CaseInsensitiveDict
 
 from ._hypothesis import create_test
-from .constants import DEFAULT_DATA_GENERATION_METHODS, DataGenerationMethod
+from .constants import DEFAULT_DATA_GENERATION_METHODS, CodeSampleStyle, DataGenerationMethod
 from .exceptions import InvalidSchema
 from .hooks import HookContext, HookDispatcher, HookScope, dispatch
 from .models import APIOperation, Case
 from .stateful import APIStateMachine, Stateful, StatefulTest
 from .types import Filter, FormData, GenericTest, NotSet
-from .utils import NOT_SET, Err, GenericResponse, Ok, Result
+from .utils import NOT_SET, Err, GenericResponse, GivenInput, Ok, Result, given_proxy
 
 
 class MethodsDict(CaseInsensitiveDict):
@@ -42,7 +41,7 @@ class MethodsDict(CaseInsensitiveDict):
             raise KeyError(message) from exc
 
 
-@attr.s()  # pragma: no mutate
+@attr.s(eq=False)  # pragma: no mutate
 class BaseSchema(Mapping):
     raw_schema: Dict[str, Any] = attr.ib()  # pragma: no mutate
     location: Optional[str] = attr.ib(default=None)  # pragma: no mutate
@@ -59,6 +58,7 @@ class BaseSchema(Mapping):
     data_generation_methods: Iterable[DataGenerationMethod] = attr.ib(
         default=DEFAULT_DATA_GENERATION_METHODS
     )  # pragma: no mutate
+    code_sample_style: CodeSampleStyle = attr.ib(default=CodeSampleStyle.default())  # pragma: no mutate
 
     def __iter__(self) -> Iterator[str]:
         return iter(self.operations)
@@ -152,6 +152,7 @@ class BaseSchema(Mapping):
         func: Callable,
         settings: Optional[hypothesis.settings] = None,
         seed: Optional[int] = None,
+        _given_kwargs: Optional[Dict[str, GivenInput]] = None,
     ) -> Generator[Tuple[Result[Tuple[APIOperation, Callable], InvalidSchema], DataGenerationMethod], None, None]:
         """Generate all operations and Hypothesis tests for them."""
         for result in self.get_all_operations():
@@ -163,6 +164,7 @@ class BaseSchema(Mapping):
                         settings=settings,
                         seed=seed,
                         data_generation_method=data_generation_method,
+                        _given_kwargs=_given_kwargs,
                     )
                     yield Ok((result.ok(), test)), data_generation_method
                 else:
@@ -177,8 +179,12 @@ class BaseSchema(Mapping):
         validate_schema: Union[bool, NotSet] = NOT_SET,
         skip_deprecated_operations: Union[bool, NotSet] = NOT_SET,
         data_generation_methods: Union[Iterable[DataGenerationMethod], NotSet] = NOT_SET,
+        code_sample_style: Union[str, NotSet] = NOT_SET,
     ) -> Callable:
         """Mark a test function as a parametrized one."""
+        _code_sample_style = (
+            CodeSampleStyle.from_str(code_sample_style) if isinstance(code_sample_style, str) else code_sample_style
+        )
 
         def wrapper(func: GenericTest) -> GenericTest:
             HookDispatcher.add_dispatcher(func)
@@ -191,34 +197,34 @@ class BaseSchema(Mapping):
                 validate_schema=validate_schema,
                 skip_deprecated_operations=skip_deprecated_operations,
                 data_generation_methods=data_generation_methods,
+                code_sample_style=_code_sample_style,  # type: ignore
             )
             return func
 
         return wrapper
 
-    def given(self, *args: Union[SearchStrategy, InferType], **kwargs: Union[SearchStrategy, InferType]) -> Callable:
+    def given(self, *args: GivenInput, **kwargs: GivenInput) -> Callable:
         """Proxy Hypothesis strategies to ``hypothesis.given``."""
-
-        def wrapper(func: GenericTest) -> GenericTest:
-            func._schemathesis_given_args = args  # type: ignore
-            func._schemathesis_given_kwargs = kwargs  # type: ignore
-            return func
-
-        return wrapper
+        return given_proxy(*args, **kwargs)
 
     def clone(
         self,
         *,
+        base_url: Union[Optional[str], NotSet] = NOT_SET,
         test_function: Optional[GenericTest] = None,
         method: Optional[Filter] = NOT_SET,
         endpoint: Optional[Filter] = NOT_SET,
         tag: Optional[Filter] = NOT_SET,
         operation_id: Optional[Filter] = NOT_SET,
+        app: Any = NOT_SET,
         hooks: Union[HookDispatcher, NotSet] = NOT_SET,
         validate_schema: Union[bool, NotSet] = NOT_SET,
         skip_deprecated_operations: Union[bool, NotSet] = NOT_SET,
         data_generation_methods: Union[Iterable[DataGenerationMethod], NotSet] = NOT_SET,
+        code_sample_style: Union[CodeSampleStyle, NotSet] = NOT_SET,
     ) -> "BaseSchema":
+        if base_url is NOT_SET:
+            base_url = self.base_url
         if method is NOT_SET:
             method = self.method
         if endpoint is NOT_SET:
@@ -227,6 +233,8 @@ class BaseSchema(Mapping):
             tag = self.tag
         if operation_id is NOT_SET:
             operation_id = self.operation_id
+        if app is NOT_SET:
+            app = self.app
         if validate_schema is NOT_SET:
             validate_schema = self.validate_schema
         if skip_deprecated_operations is NOT_SET:
@@ -235,21 +243,24 @@ class BaseSchema(Mapping):
             hooks = self.hooks
         if data_generation_methods is NOT_SET:
             data_generation_methods = self.data_generation_methods
+        if code_sample_style is NOT_SET:
+            code_sample_style = self.code_sample_style
 
         return self.__class__(
             self.raw_schema,
             location=self.location,
-            base_url=self.base_url,
+            base_url=base_url,  # type: ignore
             method=method,
             endpoint=endpoint,
             tag=tag,
             operation_id=operation_id,
-            app=self.app,
+            app=app,
             hooks=hooks,  # type: ignore
             test_function=test_function,
             validate_schema=validate_schema,  # type: ignore
             skip_deprecated_operations=skip_deprecated_operations,  # type: ignore
             data_generation_methods=data_generation_methods,  # type: ignore
+            code_sample_style=code_sample_style,  # type: ignore
         )
 
     def get_local_hook_dispatcher(self) -> Optional[HookDispatcher]:
